@@ -20,4 +20,4 @@ mkdir -p data/sources/taxi
 (cd data/sources/taxi; wget https://d37ci6vzurychx.cloudfront.net/trip-data/yellow_tripdata_2015-12.parquet )
 
 mkdir -p data/sources/github
-(cd data/sources/github; wget http://data.gharchive.org/2015-11-{01..15}-{0..23}.json.gz)
+(cd data/sources/github; wget https://data.gharchive.org/2015-11-{01..15}-{0..23}.json.gz)
