@@ -118,6 +118,11 @@ public enum OrcConf {
       "If the number of distinct keys in a dictionary is greater than this\n" +
           "fraction of the total number of non-null rows, turn off \n" +
           "dictionary encoding.  Use 1 to always use dictionary encoding."),
+  DICTIONARY_MAX_SIZE_IN_BYTES("orc.dictionary.max.size.bytes",
+      "orc.dictionary.max.size.bytes",
+      16 * 1024 * 1024,
+      "If the total size of the dictionary is greater than this\n" +
+          ", turn off dictionary encoding. Use 0 to disable this check."),
   ROW_INDEX_STRIDE_DICTIONARY_CHECK("orc.dictionary.early.check",
       "hive.orc.row.index.stride.dictionary.check",
       true,
@@ -182,6 +187,11 @@ public enum OrcConf {
       "added to all of the writers.  Valid range is [1,10000] and is primarily meant for" +
       "testing.  Setting this too low may negatively affect performance."
         + " Use orc.stripe.row.count instead if the value larger than orc.stripe.row.count."),
+  STRIPE_SIZE_CHECKRATIO("orc.stripe.size.check.ratio",
+      "orc.stripe.size.check.ratio",
+      2.0,
+      "Flush stripe if the tree writer size in bytes is larger than (this * orc.stripe.size). " +
+          "Use 0 to disable this check."),
   OVERWRITE_OUTPUT_FILE("orc.overwrite.output.file", "orc.overwrite.output.file", false,
     "A boolean flag to enable overwriting of the output file if it already exists.\n"),
   IS_SCHEMA_EVOLUTION_CASE_SENSITIVE("orc.schema.evolution.case.sensitive",
