@@ -111,7 +111,8 @@ public class WriterImpl implements WriterInternal, MemoryManager.Callback {
   private final MemoryManager memoryManager;
   private long previousAllocation = -1;
   private long memoryLimit;
-  private final long ROWS_PER_CHECK;
+  private final long rowsPerCheck;
+  private final double stripeSizePerCheck;
   private long rowsSinceCheck = 0;
   private final OrcFile.Version version;
   private final Configuration conf;
@@ -219,11 +220,13 @@ public class WriterImpl implements WriterInternal, MemoryManager.Callback {
     }
 
     // ensure that we are able to handle callbacks before we register ourselves
-    ROWS_PER_CHECK = Math.min(opts.getStripeRowCountValue(),
+    rowsPerCheck = Math.min(opts.getStripeRowCountValue(),
         OrcConf.ROWS_BETWEEN_CHECKS.getLong(conf));
     this.stripeRowCount= opts.getStripeRowCountValue();
     this.stripeSize = opts.getStripeSize();
     memoryLimit = stripeSize;
+    double stripeSizeCheckRatio = OrcConf.STRIPE_SIZE_CHECKRATIO.getDouble(conf);
+    stripeSizePerCheck = stripeSizeCheckRatio <= 0 ? 0 : stripeSizeCheckRatio * stripeSize;
     memoryManager = opts.getMemoryManager();
     memoryManager.addWriter(path, stripeSize, this);
 
@@ -292,13 +295,21 @@ public class WriterImpl implements WriterInternal, MemoryManager.Callback {
       case ZLIB:
         return new ZlibCodec();
       case SNAPPY:
-        return new SnappyCodec();
+        if ("aircompressor".equalsIgnoreCase(System.getProperty("orc.compress.snappy.impl"))) {
+          return new SnappyCodec();
+        } else {
+          return new XerialSnappyCodec();
+        }
       case LZO:
         return new AircompressorCodec(kind, new LzoCompressor(),
             new LzoDecompressor());
       case LZ4:
-        return new AircompressorCodec(kind, new Lz4Compressor(),
-            new Lz4Decompressor());
+        if ("aircompressor".equalsIgnoreCase(System.getProperty("orc.compress.lz4.impl"))) {
+          return new AircompressorCodec(kind, new Lz4Compressor(),
+              new Lz4Decompressor());
+        } else {
+          return new Lz4Codec();
+        }
       case ZSTD:
         if ("java".equalsIgnoreCase(System.getProperty("orc.compression.zstd.impl"))) {
           return new AircompressorCodec(kind, new ZstdCompressor(),
@@ -325,9 +336,10 @@ public class WriterImpl implements WriterInternal, MemoryManager.Callback {
   }
 
   private boolean checkMemory() throws IOException {
-    if (rowsSinceCheck >= ROWS_PER_CHECK) {
+    long size = rowsSinceCheck < rowsPerCheck && stripeSizePerCheck == 0
+        ? 0 : treeWriter.estimateMemory();
+    if (rowsSinceCheck >= rowsPerCheck || size > stripeSizePerCheck) {
       rowsSinceCheck = 0;
-      long size = treeWriter.estimateMemory();
       if (LOG.isDebugEnabled()) {
         LOG.debug("ORC writer " + physicalWriter + " size = " + size +
             " memoryLimit = " + memoryLimit + " rowsInStripe = " + rowsInStripe +
