@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.orc;
 
-import com.google.common.collect.Lists;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hive.ql.exec.vector.BytesColumnVector;
@@ -33,6 +33,7 @@ import org.junit.jupiter.api.TestInfo;
 import java.io.File;
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
+import java.util.ArrayList;
 import java.util.List;
 import java.util.Random;
 
@@ -158,7 +159,7 @@ public class TestOrcNullOptimization implements TestConf {
 
     RecordReader rows = reader.rows();
 
-    List<Boolean> expected = Lists.newArrayList();
+    List<Boolean> expected = new ArrayList<>();
     for (StripeInformation sinfo : reader.getStripes()) {
       expected.add(false);
     }
@@ -166,7 +167,7 @@ public class TestOrcNullOptimization implements TestConf {
     expected.set(0, true);
     expected.set(expected.size() - 1, true);
 
-    List<Boolean> got = Lists.newArrayList();
+    List<Boolean> got = new ArrayList<>();
     // check if the strip footer contains PRESENT stream
     for (StripeInformation sinfo : reader.getStripes()) {
       OrcProto.StripeFooter sf = ((RecordReaderImpl) rows).readStripeFooter(sinfo);
@@ -273,12 +274,12 @@ public class TestOrcNullOptimization implements TestConf {
     RecordReader rows = reader.rows();
 
     // none of the stripes will have PRESENT stream
-    List<Boolean> expected = Lists.newArrayList();
+    List<Boolean> expected = new ArrayList<>();
     for (StripeInformation sinfo : reader.getStripes()) {
       expected.add(false);
     }
 
-    List<Boolean> got = Lists.newArrayList();
+    List<Boolean> got = new ArrayList<>();
     // check if the strip footer contains PRESENT stream
     for (StripeInformation sinfo : reader.getStripes()) {
       OrcProto.StripeFooter sf = ((RecordReaderImpl) rows).readStripeFooter(sinfo);
@@ -372,13 +373,13 @@ public class TestOrcNullOptimization implements TestConf {
 
     RecordReader rows = reader.rows();
     // only the last strip will have PRESENT stream
-    List<Boolean> expected = Lists.newArrayList();
+    List<Boolean> expected = new ArrayList<>();
     for (StripeInformation sinfo : reader.getStripes()) {
       expected.add(false);
     }
     expected.set(expected.size() - 1, true);
 
-    List<Boolean> got = Lists.newArrayList();
+    List<Boolean> got = new ArrayList<>();
     // check if the strip footer contains PRESENT stream
     for (StripeInformation sinfo : reader.getStripes()) {
       OrcProto.StripeFooter sf = ((RecordReaderImpl) rows).readStripeFooter(sinfo);
