@@ -6,16 +6,18 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.orc;
 
-import com.google.common.collect.Lists;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hive.ql.exec.vector.TimestampColumnVector;
@@ -42,6 +44,7 @@ import java.io.File;
 import java.sql.Timestamp;
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 import java.util.TimeZone;
@@ -118,7 +121,7 @@ public class TestOrcTimezonePPD implements TestConf {
       OrcFile.writerOptions(conf).setSchema(schema).stripeSize(100000)
         .bufferSize(10000));
     assertEquals(writerTimeZone, TimeZone.getDefault().getID());
-    List<String> ts = Lists.newArrayList();
+    List<String> ts = new ArrayList<>();
     ts.add("2007-08-01 00:00:00.0");
     ts.add("2007-08-01 04:00:00.0");
     VectorizedRowBatch batch = schema.createRowBatch();
@@ -204,7 +207,7 @@ public class TestOrcTimezonePPD implements TestConf {
       OrcFile.writerOptions(conf).setSchema(schema).stripeSize(100000)
         .bufferSize(10000).bloomFilterColumns("ts").writerVersion(OrcFile.WriterVersion.ORC_101));
     assertEquals(writerTimeZone, TimeZone.getDefault().getID());
-    List<String> ts = Lists.newArrayList();
+    List<String> ts = new ArrayList<>();
     ts.add("2007-08-01 00:00:00.0");
     ts.add("2007-08-01 04:00:00.0");
     VectorizedRowBatch batch = schema.createRowBatch();
@@ -277,7 +280,7 @@ public class TestOrcTimezonePPD implements TestConf {
       OrcFile.writerOptions(conf).setSchema(schema).stripeSize(100000)
         .bufferSize(10000).bloomFilterColumns("ts"));
     assertEquals(writerTimeZone, TimeZone.getDefault().getID());
-    List<String> ts = Lists.newArrayList();
+    List<String> ts = new ArrayList<>();
     ts.add("2007-08-01 00:00:00.0");
     ts.add("2007-08-01 04:00:00.0");
     VectorizedRowBatch batch = schema.createRowBatch();
